@@ -3,12 +3,11 @@ from __future__ import annotations
 import argparse
 from sys import version_info
 
-import psutil
 from textual.app import App
 
 from .__about__ import __version__
-from ._battery import Battery
 from ._cpu import CPU
+from ._disk import Disk
 from ._info import InfoLine
 from ._mem import Mem
 from ._net import Net
@@ -71,50 +70,29 @@ def run(argv=None):
             # 34/55: approx golden ratio. See
             # <https://gist.github.com/nschloe/ab6c3c90b4a6bc02c40405803fa8fa35>
             # for the error.
-            grid.add_column(fraction=34, name="left")
-            grid.add_column(fraction=55, name="right")
+            grid.add_column(fraction=55, name="left")
+            grid.add_column(fraction=34, name="right")
 
-            if psutil.sensors_battery() is None:
-                grid.add_row(size=1, name="topline")
-                grid.add_row(fraction=1, name="top")
-                grid.add_row(fraction=1, name="center")
-                grid.add_row(fraction=1, name="bottom")
-                grid.add_areas(
-                    area0="left-start|right-end,topline",
-                    area1="left-start|right-end,top",
-                    area2a="left,center",
-                    area2b="left,bottom",
-                    area3="right,center-start|bottom-end",
-                )
-                grid.place(
-                    area0=InfoLine(),
-                    area1=CPU(),
-                    area2a=Mem(),
-                    area2b=Net(args.net),
-                    area3=ProcsList(),
-                )
-            else:
-                grid.add_row(size=1, name="topline")
-                grid.add_row(fraction=3, name="top")
-                grid.add_row(fraction=1, name="center1")
-                grid.add_row(fraction=3, name="center2")
-                grid.add_row(fraction=3, name="bottom")
-                grid.add_areas(
-                    area0="left-start|right-end,topline",
-                    area1="left-start|right-end,top",
-                    area2a="left,center1",
-                    area2b="left,center2",
-                    area2c="left,bottom",
-                    area3="right,center1-start|bottom-end",
-                )
-                grid.place(
-                    area0=InfoLine(),
-                    area1=CPU(),
-                    area2a=Battery(),
-                    area2b=Mem(),
-                    area2c=Net(args.net),
-                    area3=ProcsList(),
-                )
+            grid.add_row(size=1, name="r0")
+            grid.add_row(fraction=1, name="r1")
+            grid.add_row(fraction=1, name="r2")
+            grid.add_row(fraction=1, name="r3")
+            grid.add_areas(
+                area0="left-start|right-end,r0",
+                area1="left,r1",
+                area2a="right,r1",
+                area2b="right,r2",
+                area2c="right,r3",
+                area3="left,r2-start|r3-end",
+            )
+            grid.place(
+                area0=InfoLine(),
+                area1=CPU(),
+                area2a=Mem(),
+                area2b=Disk(),
+                area2c=Net(args.net),
+                area3=ProcsList(),
+            )
 
         async def on_load(self, _):
             await self.bind("q", "quit", "quit")
