@@ -1,4 +1,6 @@
-import cpuinfo
+import re
+from pathlib import Path
+
 import psutil
 from rich import box
 from rich.panel import Panel
@@ -8,8 +10,6 @@ from textual.widget import Widget
 
 from .braille_stream import BrailleStream
 
-# from textual import log
-
 
 def val_to_color(val: float, minval: float, maxval: float) -> str:
     t = (val - minval) / (maxval - minval)
@@ -32,6 +32,89 @@ def flatten(lst):
     return [item for sublist in lst for item in sublist]
 
 
+def get_cpu_model():
+    # cpuinfo does computation in addition to reading data, see
+    # <https://github.com/workhorsy/py-cpuinfo/issues/155#issuecomment-678923252>.
+    # Try to work around this.
+    # TODO keep an eye on the above bug.
+    try:
+        # On Linux, the file contains lines like
+        # ```
+        # model name	: Intel(R) Core(TM) i5-8350U CPU @ 1.70GHz
+        # ```
+        with open("/proc/cpuinfo") as f:
+            content = f.read()
+        m = re.search(r"model name\t: (.*)", content)
+        model_name = m.group(1)
+    except Exception:
+        import cpuinfo
+
+        model_name = cpuinfo.get_cpu_info()["brand_raw"]
+    return model_name
+
+
+def get_current_temps():
+    # First try manually reading the temperatures. (pyutil is slow.)
+    for key in ["coretemp", "k10temp"]:
+        path = Path(f"/sys/devices/platform/{key}.0/hwmon/hwmon6/")
+        if not path.is_dir():
+            continue
+
+        k = 1
+        temps = []
+        while True:
+            file = path / f"temp{k}_input"
+            if not file.exists():
+                break
+            with open(file) as f:
+                content = f.read()
+            temps.append(int(content) / 1000)
+            k += 1
+
+        return temps
+
+    # Not try psutil.sensors_temperatures().
+    # Slow, see <https://github.com/giampaolo/psutil/issues/2082>.
+    try:
+        temps = psutil.sensors_temperatures()
+    except AttributeError:
+        return None
+    else:
+        # coretemp: intel, k10temp: amd
+        # <https://github.com/nschloe/tiptop/issues/37>
+        for key in ["coretemp", "k10temp"]:
+            if key not in temps:
+                continue
+            return [t.current for t in temps[key]]
+
+    return None
+
+
+def get_current_freq():
+    # psutil.cpu_freq() is slow, so first try something else:
+    # <https://github.com/nschloe/tiptop/issues/37>
+    candidates = [
+        "/sys/devices/system/cpu/cpufreq/policy0/scaling_cur_freq",
+        "/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq",
+    ]
+    for candidate in candidates:
+        if Path(candidate).exists():
+            with open(candidate) as f:
+                content = f.read()
+            return int(content) / 1000
+
+    try:
+        cpu_freq = psutil.cpu_freq().current
+    except Exception:
+        # https://github.com/nschloe/tiptop/issues/25#issuecomment-1061390966
+        return None
+
+    if psutil.__version__ == "5.9.0" and cpu_freq < 10:
+        # Work around <https://github.com/giampaolo/psutil/issues/2049>
+        cpu_freq *= 1000
+    return cpu_freq
+
+
 class CPU(Widget):
     def on_mount(self):
         self.width = 0
@@ -54,44 +137,28 @@ class CPU(Widget):
             # BlockCharStream(10, 1, 0.0, 100.0) for _ in range(num_threads)
         ]
 
-        self.tempkey = None
-        self.has_cpu_temp = False
-        self.has_core_temps = False
+        temps = get_current_temps()
 
-        try:
-            temps = psutil.sensors_temperatures()
-        except AttributeError:
-            pass
+        if temps is None:
+            self.has_cpu_temp = False
+            self.has_core_temps = False
         else:
-            # coretemp: intel, k10temp: amd
-            # <https://github.com/nschloe/tiptop/issues/37>
-            for key in ["coretemp", "k10temp"]:
-                if key in temps:
-                    self.tempkey = key
-                    self.has_cpu_temp = len(temps[key]) > 0
-                    self.has_core_temps = len(temps[key]) == 1 + self.num_cores
-                    break
+            self.has_cpu_temp = len(temps) > 0
+            self.has_core_temps = len(temps) == 1 + self.num_cores
 
             temp_low = 30.0
+            # TODO read from file
+            temp_high = 100.0
 
             if self.has_cpu_temp:
-                assert self.tempkey is not None
                 self.temp_total_stream = BrailleStream(
-                    50, 7, temp_low, temps[self.tempkey][0].high or 100.0, flipud=True
+                    50, 7, temp_low, temp_high, flipud=True
                 )
 
             if self.has_core_temps:
-                assert self.tempkey is not None
                 self.core_temp_streams = [
-                    BrailleStream(
-                        5,
-                        1,
-                        temp_low,
-                        temps[self.tempkey][k + 1].high
-                        or temps[self.tempkey][0].high
-                        or 100.0,
-                    )
-                    for k in range(self.num_cores)
+                    BrailleStream(5, 1, temp_low, temp_high)
+                    for _ in range(self.num_cores)
                 ]
 
         self.has_fan_rpm = False
@@ -125,17 +192,17 @@ class CPU(Widget):
             box=box.SQUARE,
             expand=False,
         )
-        self.info_box_width = 0
 
-        brand_raw = cpuinfo.get_cpu_info()["brand_raw"]
         self.panel = Panel(
             "",
-            title=f"cpu - {brand_raw}",
+            title=f"[b]cpu[/] - {get_cpu_model()}",
             title_align="left",
-            border_style="blue",
+            border_style="white",
             box=box.SQUARE,
         )
 
+        # immediately collect data to refresh info_box_width
+        self.collect_data()
         self.set_interval(2.0, self.collect_data)
 
     def collect_data(self):
@@ -149,18 +216,15 @@ class CPU(Widget):
 
         # CPU temperatures
         if self.has_cpu_temp or self.has_core_temps:
-            temps = psutil.sensors_temperatures()
+            temps = get_current_temps()
+            assert temps is not None
 
             if self.has_cpu_temp:
-                assert self.tempkey is not None
-                self.temp_total_stream.add_value(temps[self.tempkey][0].current)
+                self.temp_total_stream.add_value(temps[0])
 
             if self.has_core_temps:
-                assert self.tempkey is not None
-                for stream, temp in zip(
-                    self.core_temp_streams, temps[self.tempkey][1:]
-                ):
-                    stream.add_value(temp.current)
+                for stream, temp in zip(self.core_temp_streams, temps[1:]):
+                    stream.add_value(temp)
 
         lines_cpu = self.cpu_total_stream.graph
         current_val_string = f"{self.cpu_total_stream.values[-1]:5.1f}%"
@@ -188,7 +252,7 @@ class CPU(Widget):
         if self.has_fan_rpm:
             fan_current = list(psutil.sensors_fans().values())[0][0].current
 
-            # See command above
+            # See comment above
             if fan_current == 65535:
                 fan_current = self.fan_stream.maxval
 
@@ -198,8 +262,9 @@ class CPU(Widget):
 
             self.fan_stream.add_value(fan_current)
             string = f" {fan_current}rpm"
-            graph = (
-                "[cyan]" + self.fan_stream.graph[-1][: -len(string)] + string + "[/]"
+            graph = Text(
+                self.fan_stream.graph[-1][: -len(string)] + string,
+                style="cyan",
             )
             t.add_row(graph, "")
 
@@ -232,9 +297,9 @@ class CPU(Widget):
 
         self.info_box.renderable = "\n".join(lines)
 
-        try:
-            cpu_freq = psutil.cpu_freq().current
-        except Exception:
+        cpu_freq = get_current_freq()
+
+        if cpu_freq is None:
             # https://github.com/nschloe/tiptop/issues/25
             self.info_box.subtitle = None
         else:
