@@ -42,18 +42,24 @@ class InfoLine(Widget):
         self.boot_time = psutil.boot_time()
 
     def render(self):
-        uptime_s = time.time() - self.boot_time
-        d = datetime(1, 1, 1) + timedelta(seconds=uptime_s)
-        right = [f"up {d.day - 1}d, {d.hour}:{d.minute:02d}h"]
+        uptime = timedelta(seconds=time.time() - self.boot_time)
+        h, m = seconds_to_h_m(uptime.seconds)
 
-        battery = psutil.sensors_battery()
-        if battery is not None:
-            bat_style = "[red reverse bold]" if battery.percent < 15 else ""
-            bat_style_close = "[/]" if battery.percent < 15 else ""
-            bat_symbol = "🔌" if battery.power_plugged else "🔋"
-            right.append(
-                f"{bat_style}{bat_symbol} {round(battery.percent)}%{bat_style_close}"
-            )
+        right = [f"up {uptime.days}d, {h}:{m:02d}h"]
+
+        bat = psutil.sensors_battery()
+        if bat is not None:
+            # hh, mm = seconds_to_h_m(bat.secsleft)
+            bat_string = f"bat {bat.percent:.1f}%"
+            if bat.power_plugged:
+                bat_string = "[green]" + bat_string + "[/]"
+            elif bat.percent < 10:
+                bat_string = "[red reverse bold]" + bat_string + "[/]"
+            elif bat.percent < 15:
+                bat_string = "[red]" + bat_string + "[/]"
+            elif bat.percent < 20:
+                bat_string = "[yellow]" + bat_string + "[/]"
+            right.append(bat_string)
 
         table = Table(show_header=False, expand=True, box=None, padding=0)
         if self.width < 100:
@@ -65,10 +71,14 @@ class InfoLine(Widget):
             table.add_column(justify="center", no_wrap=True, ratio=1)
             table.add_column(justify="right", no_wrap=True, ratio=1)
             table.add_row(
-                self.left_string, datetime.now().strftime("%c"), ", ".join(right)
+                self.left_string, datetime.now().strftime("%c"), "  ".join(right)
             )
         return table
 
     async def on_resize(self, event):
         self.width = event.width
         self.height = event.height
+
+
+def seconds_to_h_m(seconds):
+    return seconds // 3600, (seconds // 60) % 60
