@@ -7,8 +7,10 @@ from rich import box
 from rich.console import Group
 from rich.panel import Panel
 from rich.table import Table
+from rich.text import Text
 from textual.widget import Widget
 
+from .__about__ import __version__
 from ._helpers import sizeof_fmt
 from .braille_stream import BrailleStream
 
@@ -42,14 +44,17 @@ def _autoselect_interface():
         else:
             score_dict[name] = 3
 
-    # Get key with max score
-    # https://stackoverflow.com/a/280156/353337
-    return max(score_dict, key=score_dict.get)
+    # Amongst all keys with max score, get the alphabetically first.
+    # This is to prefer en0 over en5, <https://github.com/nschloe/tiptop/issues/81>.
+    max_score = max(score_dict.values())
+    max_keys = [key for key, score in score_dict.items() if score == max_score]
+    return sorted(max_keys)[0]
 
 
 class Net(Widget):
     def __init__(self, interface: str | None = None):
         self.interface = _autoselect_interface() if interface is None else interface
+        self.tiptop_string = f"tiptop v{__version__}"
         super().__init__()
 
     def on_mount(self):
@@ -79,10 +84,13 @@ class Net(Widget):
         self.group = Group(self.table, "", "")
         self.panel = Panel(
             self.group,
-            title=f"net - {self.interface}",
-            border_style="red",
+            title=f"[b]net[/] - {self.interface}",
+            # border_style="red",
+            border_style="white",
             title_align="left",
             box=box.SQUARE,
+            subtitle=self.tiptop_string,
+            subtitle_align="right",
         )
 
         self.last_net = None
@@ -162,19 +170,22 @@ class Net(Widget):
                 f"total {total_sent_string}",
             ]
         )
-
-        self.table.columns[0]._cells[0] = (
-            "[green]" + "\n".join(self.recv_stream.graph) + "[/]"
-        )
-        self.table.columns[0]._cells[1] = (
-            "[blue]" + "\n".join(self.sent_stream.graph) + "[/]"
-        )
+        self.refresh_graphs()
 
         self.refresh()
 
+    def refresh_graphs(self):
+        self.table.columns[0]._cells[0] = Text(
+            "\n".join(self.recv_stream.graph), style="green"
+        )
+        self.table.columns[0]._cells[1] = Text(
+            "\n".join(self.sent_stream.graph), style="blue"
+        )
+
     def render(self):
         return self.panel
 
     async def on_resize(self, event):
         self.sent_stream.reset_width(event.width - 25)
         self.recv_stream.reset_width(event.width - 25)
+        self.refresh_graphs()
